@@ -254,12 +254,15 @@ class Client(object):
                                 settings['chatkey'] + "&roomId=" +
                                 str(settings['room']) + "&t=" +
                                 time)
-        content = re.findall(r'.:::(.*)', data.content)
-        if content:
-            loads = json.loads(content[0])
-            return loads
-        else:
-            return None
+        contents = re.findall(r'({.*?})', data.content)
+        array = []
+        for content in contents:
+            if content:
+                loads = json.loads(content[0])
+                array.append(content)
+            else:
+                pass
+        return array
 
     def connection(self):
         var = self.__connection(self.settings, self.xhr)
@@ -302,8 +305,8 @@ class ChatBot(object):
     def start(self):
         in_chat = 0
         while 1:
-            connect = self.c.connection()
-            if connect:
+            connects = self.c.connection()
+            for connect in connects:
                 in_chat += 1
                 e = Event(connect)
                 if in_chat == 1:
